@@ -1,9 +1,11 @@
-__author__="Francisco Munoz,Aldo Romero,Sobhit Singh,Uthpala Herath,Pedram Tavadze,Eric Bousquet,Xu He"
-__copyright__ = "Copyright 2019"
-__version__ = "3.8.9"
-__email__ = "fvmunoz@gmail.com/alromero@mail.wvu.edu/ukh0001@mix.wvu.edu/petavazohi@mix.wvu.edu"
+__author__ = "Francisco Munoz,Aldo Romero,Sobhit Singh,Uthpala Herath,Pedram Tavadze,Eric Bousquet,Xu He"
+__copyright__ = "Copyright 2020"
+__version__ = "5.1.2"
+__email__ = (
+    "fvmunoz@gmail.com/alromero@mail.wvu.edu/ukh0001@mix.wvu.edu/petavazohi@mix.wvu.edu"
+)
 __status__ = "Development"
-__date__ ="Sep 9, 2019"
+__date__ = "Mar 5th, 2020"
 
 # Copyright (C) 2019 Francisco Munoz,Aldo Romero,Sobhit Singh,Uthpala Herath,Pedram Tavadze,Eric Bousquet,Xu He
 #
@@ -31,16 +33,20 @@ import matplotlib.pyplot as plt
 import seekpath
 import ase
 import skimage
+import pyfiglet
 
 from pyprocar.utilsprocar import UtilsProcar
 from pyprocar.procarparser import ProcarParser
 from pyprocar.procarplot import ProcarPlot
-from pyprocar.procarplotcompare import	ProcarPlotCompare
 from pyprocar.procarfilefilter import ProcarFileFilter
 from pyprocar.procarselect import ProcarSelect
 from pyprocar.fermisurface import FermiSurface
 from pyprocar.procarsymmetry import ProcarSymmetry
 
+# ELK
+from pyprocar.elkparser import ElkParser
+
+
 from .scriptBandsplot import bandsplot
 from .scriptCat import cat
 from .scriptFermi2D import fermi2D
@@ -49,7 +55,6 @@ from .scriptFilter import filter
 from .scriptRepair import repair
 from .scriptVector import Vector
 from .scriptKmesh2D import generate2dkmesh
-from .scriptAbinitMerge import mergeabinit
 from .scriptKpath import kpath
-from .scriptCompareBands import bandscompare
 from .scriptUnfold import unfold
+from .splash import welcome
